%fig4print
% Function which creates or modifies a figure to a desired size.
% It will return a figure which is a scale version of the desired size
% that fits into the screen. The DPI out is the print DPI which should be
% used to print the screen to gain equivalent resolution at the desired
% paper size.
%
% LAST UPDATED by Andy French August 2014
%
% Syntax: fig = fig4print( fig, paper )
%
% fig     Handle to figure. If [], a new figure is created.
% paper   String describing paper size e.g. 'A4 portrait'
% DPI     Desired print output dots per inch
%
% print_DPI  Set the print DPI to be this
%
% Example: [fig,print_DPI] = fig4print( [], 'A4 portrait', 300 );

function [fig,print_DPI] = fig4print( fig, paper, DPI )

%Create figure if none already exists. Otherwise make figure fig current.
if isempty(fig)
    fig = figure;
else
    figure( fig );
end

%Get screen dimensions in pixels.
set(0,'units','pixels') ;
screen_size=get(0,'Screensize');
screen_width_pix = screen_size(3);
screen_height_pix = screen_size(4);

%Get desired figure size in cm
[width_cm,height_cm] = papersize(paper);

%Determine figure dimensions such that the longest dimension is half that
%of the screen
if width_cm > height_cm
    %Landscape
    fig_width_pix = round( screen_width_pix/2 );
    fig_height_pix = round( (height_cm/width_cm) * fig_width_pix );
else
    %Portrait
    fig_height_pix = round( screen_height_pix/2 );
    fig_width_pix = round( (width_cm/height_cm) * fig_height_pix );
end

%Modify figure dimensions, and centre. Also turn off toolbars and menus.
set( fig, 'toolbar','none', 'menubar','none', 'Units', 'Pixels' );
bottom_left_x = round( (screen_width_pix - fig_width_pix)/2 );
bottom_left_y = round( (screen_height_pix - fig_height_pix)/2 );
set( fig, 'OuterPosition', [ bottom_left_x, bottom_left_y, fig_width_pix, fig_height_pix ] );

%Set figure paper size
set( fig, 'units', 'centimeters' );
p = get( fig, 'position' );
fig_width_cm = p(3);
fig_height_cm = p(4);
set( fig, 'PaperPositionMode', 'manual' ,'PaperUnits', 'centimeters',...
    'PaperSize', [fig_width_cm,fig_height_cm],...
    'PaperPosition',[ 0, 0, fig_width_cm, fig_height_cm ] );

%Calculate print DPI
print_DPI = DPI * width_cm/fig_width_cm;

%%

%papersize
% Function which gives standard paper sizes in cm.
%
% References:
% http://www.cl.cam.ac.uk/~mgk25/iso-paper.html
% http://en.wikipedia.org/wiki/Photo_print_sizes

function [width_cm,height_cm] = papersize(paper)

if strcmp( paper,'A6 landscape')==1
    [height_cm,width_cm] = ABCsize('A6');
    
elseif strcmp( paper,'A6 portrait')==1
    [width_cm,height_cm] = ABCsize('A6');
    
elseif strcmp( paper,'A5 landscape')==1
    [height_cm,width_cm] = ABCsize('A5');
    
elseif strcmp( paper,'A5 portrait')==1
    [width_cm,height_cm] = ABCsize('A5');
    
elseif strcmp( paper,'A4 landscape')==1
    [height_cm,width_cm] = ABCsize('A4');
    
elseif strcmp( paper,'A4 portrait')==1
    [width_cm,height_cm] = ABCsize('A4');
    
elseif strcmp( paper,'A3 landscape')==1
    [height_cm,width_cm] = ABCsize('A3');
    
elseif strcmp( paper,'A3 portrait')==1
    [width_cm,height_cm] = ABCsize('A3');
    
elseif strcmp( paper,'A2 landscape')==1
    [height_cm,width_cm] = ABCsize('A2');
    
elseif strcmp( paper,'A2 portrait')==1
    [width_cm,height_cm] = ABCsize('A2');
    
elseif strcmp( paper,'A1 landscape')==1
    [height_cm,width_cm] = ABCsize('A1');
    
elseif strcmp( paper,'A1 portrait')==1
    [width_cm,height_cm] = ABCsize('A1');
    
elseif strcmp( paper,'A0 landscape')==1
    [height_cm,width_cm] = ABCsize('A0');
    
elseif strcmp( paper,'A0 portrait')==1
    [width_cm,height_cm] = ABCsize('A0');
    
elseif strcmp( paper,'6" x 4"')==1
    width_cm = 15.2;
    height_cm = 10.2;
    
elseif strcmp( paper,'7" x 5"')==1
    width_cm = 17.8;
    height_cm = 12.7;
    
elseif strcmp( paper,'8" x 6"')==1
    width_cm = 20.3;
    height_cm = 15.2;
    
elseif strcmp( paper,'10" x 12"')==1
    width_cm = 30.5;
    height_cm = 25.4;
    
elseif strcmp( paper,'10" x 15"')==1
    width_cm = 38.1;
    height_cm = 25.4;
else
    width_cm = NaN;
    height_cm = NaN;
end

%%

% Portrait sizes of A,B,C names

function [width_cm,height_cm] = ABCsize(XN)

%Break up paper size string XN
X = XN(1);
N = str2num( XN(2:end) );

%Compute size of paper /m
if strcmp(X,'A')
    width=2^(-0.25-N/2);
    height=2^(0.25-N/2);
elseif strcmp(X,'B')
    width=2^(-N/2);
    height=2^(0.5-N/2);
elseif strcmp(X,'C')
    width=2^(-1/8-N/2);
    height=2^(3/8-N/2);
else
    width=NaN;
    height=NaN;
end

%Convert to centimeters
width_cm=width*100;
height_cm=height*100;

%End of code