%fitax2fig
% Function which fits the graphic content of a specified axes within a figure to the figure.
%
% LAST UPDATED by Andy French August 2014
%
% Example: fig = figure; peaks; axis vis3d;
% fitax2fig( fig, gca ); set(fig,'toolbar', 'none', 'menubar', 'none');

function fitax2fig( fig, ax )

%Define figure window borders in pixels
border_width_pix = 8;
title_width_pix = 30;
menu_width_pix = 27;
toolbar_width_pix = 30;

%%

%Modify title_width_pix if figure has menus or a toolbar
if strcmp( get( fig, 'menubar' ), 'none' )==0
    title_width_pix = title_width_pix + menu_width_pix;
end
if strcmp( get( fig, 'toolbar' ), 'none' )==0
    title_width_pix = title_width_pix + toolbar_width_pix;
end

%%

%Set camera settings such that scene is fully captured
set( ax,'cameraviewanglemode','auto',...
    'cameratargetmode','auto','cameratargetmode','auto');
set( ax, 'units', 'normalized' );
set( ax, 'OuterPosition',[0.1,.1,0.8,0.8] );
set( ax,'LooseInset',get(ax,'TightInset'));
set( ax, 'DataAspectRatioMode','manual','PlotBoxAspectRatioMode',...
    'manual','CameraViewAngleMode','manual','units','pixels');

%Set background color of axes to be white
background_colour = get(fig,'color');
set( fig,'color',[1 1 1] );

%Obtain a bitmap image
f=getframe(fig);

%Retore background colour of figure
set( fig,'color',background_colour );

%Determine mean colour matrix
m = mean(f.cdata,3);

%Determine 2% border
dim = size(m);
width_pix = dim(2);
height_pix = dim(1);
b = round( 0.02*min([width_pix,height_pix]) );

%Determine maximum and minimum indices of pixels which are NOT white
[row_ind,col_ind] = find(m~=255);
min_row = min(row_ind);
max_row = max(row_ind);
min_col = min(col_ind);
max_col = max(col_ind);

%Hence determine width, height and aspect ratio of cropped axes
ax_width_pix = max_col - min_col + 2*b ;
ax_height_pix = max_row  - min_row + 2*b;
ax_aspect = ax_height_pix / ax_width_pix;

%Get figure pixel dimensions and compute aspect ratio
set( fig, 'units', 'pixels' );
fop = get( fig, 'outerposition' );
fig_height_pix = fop(4);
fig_width_pix = fop(3);
fig_aspect = fig_height_pix / fig_width_pix;

%Crop figure to fit axes, by width or height depending on the aspect ratios
%of the figure or axes
if fig_aspect > ax_aspect
    set( fig, 'outerposition', [ fop(1), fop(2), ax_width_pix + 2*border_width_pix,...
        ax_width_pix*fig_aspect + border_width_pix + title_width_pix ] );
else
    set( fig, 'outerposition', [ fop(1), fop(2),...
        ax_height_pix/fig_aspect + 2*border_width_pix,...
        ax_height_pix + border_width_pix + title_width_pix  ] );
end

%Centre axes in figure
fop = get( fig, 'outerposition' );
p = get( ax, 'position' );
op = get( ax, 'outerposition' );
dx = ( fop(3) - border_width_pix )/2 - ( op(1) + op(3)/2 ) ;
dy = ( fop(4) - border_width_pix - title_width_pix )/2 - ( op(2) + op(4)/2 );
set( ax, 'position',[ p(1) + dx, p(2) + dy, p(3), p(4) ] );
set( ax, 'outerposition',[ op(1) + dx, op(2) + dy, op(3), op(4) ] );

%Modify figure paper size properties
set( fig, 'units', 'centimeters' );
p = get( fig, 'position' );
set( fig, 'PaperSize', [p(3),p(4)],...
    'PaperPosition',[ 0, 0, p(3),p(4) ] );

%End of code